@@ -63,6 +63,16 @@ from canalyst_candas.configuration.config import Config
 from canalyst_candas.settings import CONFIG
 
 
+def get_ticker_list(config, ticker=""):
+    GET = Getter(config=config)
+    path_name = f"DATA/cwl20.csv"
+    df = GET.get_csv_from_s3(path_name)
+    df = df.drop(columns=["CSIN"])
+    if ticker != "":
+        df = df.loc[df["Bloomberg Ticker"] == ticker]
+    return df
+
+
 def help():
     print("Canalyst Candas help")
     print(
@@ -710,10 +720,8 @@ class ModelSet:
         extract_drivers=True,
         historical_only=False,
         allow_nulls=False,
-        mo_only=False,
     ):
         self.allow_nulls = allow_nulls
-        self.mo_only = mo_only
         self.config = config or CONFIG
         self.historical_only = historical_only
         self.period_name = period_name
@@ -756,9 +764,17 @@ class ModelSet:
 
         df_earnings = cdr.get_earnings_and_prices(yahoo_ticker, index_ticker)
         df_earnings = df_earnings[
-            ["ticker", "earnings_date", "beta_252", "alpha_5_day", "alpha_10_day"]
+            [
+                "ticker",
+                "earnings_date",
+                "beta_252",
+                "alpha_1_day",
+                "alpha_5_day",
+                "alpha_10_day",
+            ]
         ]
         df_earnings = df_earnings.sort_values("earnings_date", ascending=False)
+
         df_model = self.model_frame(
             ticker=ticker, is_historical=True, period_duration_type="fiscal_quarter"
         )
@@ -778,7 +794,9 @@ class ModelSet:
 
         if len(edq_list) < n_periods:
             n_periods = len(edq_list)
-            print("Using " + str(n_periods) + " periods available")
+            print(
+                "Price earnings dataset using " + str(n_periods) + " periods available"
+            )
 
         d = {
             "earnings_date_q": edq_list[0:n_periods],
@@ -830,7 +848,7 @@ class ModelSet:
         col_for_labels="time_series_name",
         time_series_name="MO_RIS_REV",
         tree=True,
-        notebook=True,
+        notebook=False,
     ):
         if type(ticker) == list:
             print("Please request one ticker at a time.")
@@ -969,9 +987,6 @@ class ModelSet:
 
                 df = md._model_frame
 
-                if self.mo_only == True:
-                    df = df.loc[df["time_series_name"].str.startswith("MO_")]
-
                 list_df.append(df)
 
                 if df is not None:
@@ -1023,7 +1038,6 @@ class ModelSet:
         unit_type="",
         category="",
         warning=True,
-        mo_only="",
         ticker="",
     ):
 
@@ -1045,7 +1059,6 @@ class ModelSet:
             mrq_notation,
             unit_type,
             category,
-            mo_only,
             warning,
         )
 
@@ -1314,6 +1327,7 @@ class ModelMap:
             id_split = node["id"].split("|")
             if len(id_split) > 1:
                 time_series[id_split[0]] = id_split[1]
+
         df = self.df[self.df["time_series_slug"].isin(time_series)]
 
         # root node id
@@ -1327,6 +1341,7 @@ class ModelMap:
         self.path_distances = dict(nx.all_pairs_shortest_path_length(G))
         num_drivers = 0
         distances = []
+
         for node in graph.nodes:
 
             # set level of node based on distance from root
@@ -1344,6 +1359,7 @@ class ModelMap:
             ######
 
             slug = id_split[0]
+
             period = id_split[1]
             rows = df[df["period_name"] == period]
 
@@ -1716,7 +1732,9 @@ class Model:
     def key_driver_map(self, time_series_name):
         # defaulting to MO_RIS_REV, but you could choose another time_series_name as a starting point like MO_RIS_EBIT
         model_map = self.create_model_map(
-            time_series_name=time_series_name, col_for_labels="time_series_name"
+            time_series_name=time_series_name,
+            col_for_labels="time_series_name",
+            notebook=False,
         )
 
         # list all the nodes in the model map
@@ -1942,10 +1960,7 @@ class Model:
 
         df_drivers, self.df_name_index = get_drivers_from_model(
             self.ticker,
-            self.api_headers,
-            self.config.default_dir,
-            self.config.mds_host,
-            self.config.wp_host,
+            self.config,
         )
         df_drivers = df_drivers.loc[df_drivers["historical"] == 0]
         df = (
@@ -2266,6 +2281,9 @@ class Model:
         df.to_csv(path_name + self.ticker + "_historical_data.csv")
         df_model_info = pd.DataFrame(model_info)
         df_model_info.to_csv(path_name + self.ticker + "_model_info.csv")
+
+        # Converts the "value" column from an object type to a float64 type
+        df["value"] = pd.to_numeric(df["value"])
         return df
 
     def summary(self, filter_term=""):
