@@ -6,6 +6,7 @@
 import yahoo_fin.stock_info as si
 import pandas as pd
 import numpy as np
+import string
 import statsmodels.tsa.stattools as ts
 from statsmodels.regression.rolling import RollingOLS
 
@@ -180,6 +181,7 @@ def get_price_data(
         df = df.drop(columns=["index"])
     if rolling_betas == True:
         beta = "beta_" + str(rolling_window)
+        df["adjclose_plus_1"] = df["adjclose"].shift(-1)
         df["adjclose_plus_5"] = df["adjclose"].shift(-5)
         df["adjclose_plus_10"] = df["adjclose"].shift(-10)
 
@@ -195,6 +197,7 @@ def get_price_data(
         df_sp["price_date"] = df_sp["index"]
         df_sp = df_sp.drop(columns=["index"])
         df_sp["mktclose"] = df_sp["adjclose"]
+        df_sp["mkt_plus_1"] = df_sp["mktclose"].shift(-1)
         df_sp["mkt_plus_5"] = df_sp["mktclose"].shift(-5)
         df_sp["mkt_plus_10"] = df_sp["mktclose"].shift(-10)
         df = pd.merge(
@@ -205,6 +208,7 @@ def get_price_data(
                     "price_date",
                     "mkt_change",
                     "mktclose",
+                    "mkt_plus_1",
                     "mkt_plus_5",
                     "mkt_plus_10",
                 ]
@@ -219,12 +223,16 @@ def get_price_data(
         rres = model.fit()
         df[beta] = rres.params[["mkt_change"]]
 
+        df["plus_1_return"] = df["adjclose_plus_1"] / df["adjclose"] - 1
         df["plus_5_return"] = df["adjclose_plus_5"] / df["adjclose"] - 1
         df["plus_10_return"] = df["adjclose_plus_10"] / df["adjclose"] - 1
+        df["mktclose_plus_1_return"] = df["mkt_plus_1"] / df["mktclose"] - 1
         df["mktclose_plus_5_return"] = df["mkt_plus_5"] / df["mktclose"] - 1
         df["mktclose_plus_10_return"] = df["mkt_plus_10"] / df["mktclose"] - 1
+        df["expected_1_day_return"] = df[beta] * df["mktclose_plus_1_return"]
         df["expected_5_day_return"] = df[beta] * df["mktclose_plus_5_return"]
         df["expected_10_day_return"] = df[beta] * df["mktclose_plus_10_return"]
+        df["alpha_1_day"] = df["plus_1_return"] - df["expected_1_day_return"]
         df["alpha_5_day"] = df["plus_5_return"] - df["expected_5_day_return"]
         df["alpha_10_day"] = df["plus_10_return"] - df["expected_10_day_return"]
 
@@ -359,9 +367,13 @@ def get_earnings_dates(ticker):
     ]
 
 
-def regress_dataframe(df, y_col, x_col, y_filter, sort_col="", n=24):
+def regress_dataframe(df, y_col, x_col, y_filter, sort_col="", n=24, z_score=False):
     import datetime as ddt
 
+    if z_score == True:
+        df[x_col] = (df[x_col] - df[x_col].mean()) / df[x_col].std(ddof=0)
+        df[y_col] = (df[y_col] - df[y_col].mean()) / df[y_col].std(ddof=0)
+
     if df.dropna().shape[0] == 0:
         print("Not enough datapoints")
         return
@@ -413,11 +425,14 @@ def get_earnings_and_prices(ticker, index_ticker):
             "epsestimate",
             "epsactual",
             "epssurprisepct",
+            "alpha_1_day",
             "alpha_5_day",
             "alpha_10_day",
             beta,
+            "plus_1_return",
             "plus_5_return",
             "plus_10_return",
+            "mktclose_plus_1_return",
             "mktclose_plus_5_return",
             "mktclose_plus_10_return",
         ]
@@ -453,7 +468,7 @@ def regress_dataframe_groups(
 
     grouped = df_data.groupby("time_series_name")  # group by each time series name
     grouped = grouped.apply(
-        lambda x: extract_lr(x, "alpha_10_day")
+        lambda x: extract_lr(x, y_name)
     )  # apply the model to the dataframe groups
     if return_grouped == True:
         df_output = (
@@ -556,16 +571,24 @@ def plot_prices_against_time_series(
     return  # plt.show()
 
 
-def plot_eps_surprise_data(df):
+def plot_eps_surprise_data(df, alpha_days="alpha_10_days"):
 
-    df["z_score_alpha_10_day"] = (df["alpha_10_day"] - df["alpha_10_day"].mean()) / df[
-        "alpha_10_day"
+    ticker = df.iloc[0]["ticker"]
+
+    df["z_score_" + alpha_days] = (df[alpha_days] - df[alpha_days].mean()) / df[
+        alpha_days
     ].std(ddof=0)
+
+    # df_z_scaled[column] = (df_z_scaled[column] - df_z_scaled[column].mean()) / df_z_scaled[column].std()
+
     df["z_score_epssurprisepct"] = (
         df["epssurprisepct"] - df["epssurprisepct"].mean()
     ) / df["epssurprisepct"].std(ddof=0)
 
     df_plot = df
+    i_correlation = round(
+        df_plot["z_score_epssurprisepct"].corr(df["z_score_" + alpha_days]), 2
+    )
 
     colors = {
         "red": "#ff207c",
@@ -583,19 +606,20 @@ def plot_eps_surprise_data(df):
     plt.tight_layout(pad=3)
 
     date = df["price_date"]
-    close = df["z_score_alpha_10_day"]
+    close = df["z_score_" + alpha_days]
     vol = df_plot["z_score_epssurprisepct"]
 
-    plt.scatter(date, close, color=colors["blue"], label="Alpha 10 Days")
+    plt.scatter(date, close, color=colors["blue"], label="Alpha Z Score")
 
-    plt.scatter(date, vol, color="black", label="Eps Surprise")
+    plt.scatter(date, vol, color="black", label="Eps Surprise Z Score")
 
     plt.gca().yaxis.tick_right()
     plt.gca().tick_params(axis="both", **config_ticks)
-    plt.gca().set_ylabel("Standard Deviation", fontsize=14)
+    plt.gca().set_ylabel("Z Score", fontsize=14)
     plt.gca().yaxis.set_label_position("right")
     plt.grid(axis="y", color="gainsboro", linestyle="-", linewidth=0.5)
     plt.legend(loc="upper left")
+    plt.title(ticker + " earnings suprise and alpha correlation:" + str(i_correlation))
     format_borders(plt.gca(), colors)
 
     return
@@ -611,6 +635,9 @@ def regress_dataframe_time_series_groups(
     category="",
     n_periods=16,
 ):
+    df_data = df_data[
+        ~df_data["time_series_name"].str.contains("other", case=False, regex=True)
+    ]
 
     if len(category_filter):
         df_data = df_data.loc[~df_data["category"].isin(category_filter)]
@@ -638,7 +665,7 @@ def regress_dataframe_time_series_groups(
 
     if df is None:
         print("Regression error: perhaps not enough datapoints")
-        return
+        return None
 
     df["ticker"] = ticker
     df["name_index"] = df["name_index"].astype(int)
@@ -646,12 +673,16 @@ def regress_dataframe_time_series_groups(
     first_col = df.pop(col_name)
     df.insert(0, col_name, first_col)
 
-    df = df.loc[df["rsquared"] < 1.00]
-    df = df.loc[df["rsquared"] > 0]
+    df = df.loc[df["rsquared"] < 0.98]
+    df = df.loc[df["rsquared"] > 0.01]
     return df
 
 
-def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=12):
+def regress_dataframe_groups(
+    df_data, y_name="", return_grouped=True, n_periods=12, regression_warnings=False
+):
+    regression_warning = {}
+    max_time_period = df_data["period_end_date"].max()
 
     period_names = list(
         df_data.groupby("period_name")
@@ -663,31 +694,46 @@ def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=
 
     warnings.filterwarnings("ignore", category=RuntimeWarning)
 
-    # return df_data
     df_data = df_data.sort_values(["time_series_name", "period_end_date"])
     df_data = df_data[df_data[y_name].notna()]
     df_data = df_data[df_data["value"].notna()]
-    # return df_data
 
     def extract_lr(x, y_name):
-        x = x.loc[x["period_name"].isin(period_names)]
-        x = x[x["value"].notna()]
-
-        if x.shape[0] != n_periods:
+        test_time_period = x["period_end_date"].max()
+        if test_time_period != max_time_period:
+            time_series_name = x.iloc[0]["time_series_name"]
+            regression_warning[time_series_name] = [
+                "Time series ends at " + str(test_time_period)
+            ]
             return None
 
-        model = smf.ols(formula="value ~ alpha_10_day", data=x)
+        x = x.loc[x["period_name"].isin(period_names)]
+        x = x[x["value"].notna()]
+        if x.shape[0] < n_periods and x.shape[0] > 0:
+            time_series_name = x.iloc[0]["time_series_name"]
+            regression_warning[time_series_name] = [
+                "Time series has " + str(x.shape[0]) + " periods"
+            ]
+        if x.shape[0] == 0:
+            return None
+
+        model = smf.ols(formula="value ~ " + y_name, data=x)
         rres = model.fit()
 
         x["intercept"] = rres.params[0]
         x["n_periods"] = x.shape[0]
         x["rsquared"] = rres.rsquared
         x["slope"] = rres.params[1]
+
         return pd.DataFrame(x)
 
     grouped = df_data.groupby("time_series_name")  # group by each time series name
     grouped = grouped.apply(lambda x: extract_lr(x, y_name))
 
+    if regression_warning and regression_warnings:
+        print("Regression warning:")
+        print(pd.DataFrame.from_dict(regression_warning, orient="index"))
+
     if return_grouped == True:
         try:
             df_output = (
@@ -704,7 +750,7 @@ def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=
                 .reset_index()
                 .sort_values("rsquared", ascending=False)
             )
-            df_output = df_output.loc[df_output["n_periods"] >= n_periods]
+            # df_output = df_output.loc[df_output["n_periods"] >= n_periods]
             return df_output[
                 [
                     "name_index",
@@ -723,7 +769,9 @@ def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=
         return grouped
 
 
-def rolling_r_squared(df_data, time_series_name, window, plot=False):
+def rolling_r_squared(
+    df_data, time_series_name, window, y_name="alpha_10_day", plot=False
+):
     # df_data = df_data.sort_values('period_end_date',ascending=False)
     category_filter = []
     df = df_data[
@@ -731,25 +779,31 @@ def rolling_r_squared(df_data, time_series_name, window, plot=False):
     ]  # [['period_name','value','earnings_date','alpha_10_day']]
 
     model = RollingOLS.from_formula(
-        "value ~ alpha_10_day",
-        data=df[["value", "alpha_10_day"]],
+        "value ~ " + str(y_name),
+        data=df[["value", y_name]],
         window=window,
     )
     rres = model.fit()
     df["intercept"] = rres.params[["Intercept"]]
-    df["slope"] = rres.params[["alpha_10_day"]]
+    df["slope"] = rres.params[[y_name]]
     df["rsquared"] = rres.rsquared
     df = df[
         [
             "period_name",
             "earnings_date",
-            "alpha_10_day",
+            y_name,
             "value",
             "slope",
             "rsquared",
             "intercept",
         ]
     ].dropna()
+
+    if df["rsquared"].isnull().all():
+        print(
+            "Regression warning: All rsquareds are null. Time series length is less than the window. Try a shorter window."
+        )
+
     if plot == False:
         return df
 
@@ -776,11 +830,27 @@ def rolling_r_squared(df_data, time_series_name, window, plot=False):
     ax3.plot(df["value"], label="Time Series Value", color=colors["blue"])
     ax3.legend(loc="upper left")
 
+    import warnings
+
+    warnings.filterwarnings("ignore")
+
+    ax1.set_xticklabels(df["period_name"])  # annoying matplotlib warning in error
+
     ax1.get_shared_x_axes().join(ax1, ax2, ax3)
-    ax1.set_xticklabels([])
+
     ax1.title.set_text(time_series_name)
     format_borders(ax1, colors)
     format_borders(ax2, colors)
     format_borders(ax3, colors)
 
     plt.show()
+
+
+def remove_stopwords(sentence):
+    my_stopwords = ["in", "Change", "YoY", ",", "%", "(Calculated)", "Total", "growth"]
+    tokens = sentence.split(" ")
+    tokens_filtered = [word for word in tokens if not word in my_stopwords]
+    tokens_filtered = [
+        "".join(c for c in s if c not in string.punctuation) for s in tokens_filtered
+    ]
+    return (" ").join(tokens_filtered)
