@@ -197,7 +197,6 @@ def filter_dataset(
     mrq_notation=False,
     unit_type="",
     category="",
-    mo_only="",
     warning=True,
 ):
 
@@ -212,12 +211,6 @@ def filter_dataset(
             "period_duration_type = 'fiscal_year' to filter."
         )
 
-    if mo_only == True:
-        df = df.loc[df["time_series_name"].str.startswith("MO_")]
-        # df = df.loc[~df["time_series_name"].str.contains("_MO_")]
-    if mo_only == False:
-        df = df.loc[~df["time_series_name"].str.startswith("MO_")]
-
     if mrq is True:
         mrq = df["MRQ"].iloc[0]
         df = df.loc[df["period_name"] == df["MRQ"]]
@@ -354,17 +347,16 @@ def map_scenario_urls(json):
 
 def get_drivers_from_model(
     ticker,
-    auth_headers,
-    default_dir=settings.DEFAULT_DIR,
-    mds_host=settings.MDS_HOST,
-    wp_host=settings.WP_HOST,
+    config,
 ):
+    default_dir = config.default_dir
+
     # check if the model exists if so use it.
     file_ticker = ticker.split(" ")[0]
 
     log = LogFile(default_dir=default_dir)
 
-    get_excel_model(ticker, auth_headers, default_dir, mds_host, wp_host)
+    get_excel_model(ticker, config, default_dir)
 
     path_name = f"{default_dir}/DATA/{file_ticker}/"
 
